import java.io.IOException;
import java.io.OutputStream;
import java.io.FileOutputStream;
import java.io.FileInputStream;
import java.io.File;

import xml.*;
import futils.Futil;

/**
 * This class acts as a driver for parsing an XML file.
 *
 *  Exercises:
 *  1)  Create a DOMParser directly against the Xerces parser, 
 *      and parse an XML file to print out the contents.
 *  2)  Repeat 1) by going through JAXP instead of using Xerces directly.
 *  3)  Perform validation using a DTD.
 *  4)  Perform validation using an XMLSchema.
 *  5)  Modify the DOM document and save it using XSLT.
 *  6)  Transform the XML file to an HTML file using XSLT.
 *
 */
public class MusicCatalog {
	
	public static void main (String argv []) {
		
            String sFile = (Futil.getReadFile (
                    "Select an XML file").getAbsolutePath ());
            System.out.println ("xml file selected: " + sFile);
            String uri = "file:" + sFile;
            File xmlFile = new File (sFile);

            OutputStream out = System.out;

            try {
                // (1)
                //-- parse the xml file using the Xerces api
                MyDomParser.parse (uri, out);
                System.exit (0);

                /*
                // (2)
                //-- parse an xml file using jaxp
                MyDomParser2 dp = new MyDomParser2 ();
                dp.parse (uri, out);
                */

                /*
                // (5)
                // add a new entry
                Item item = dp.createItem ();
                item.setMedia ("cd");
                item.setArtist ("Aaron Copeland");
                item.setTitle ("Fanfare");
                item.setYear ("1970");
                item.setMember ("Aaron Copeland");
                item.setMember ("the rest of the band");
                dp.addItem (item);

                // write the xml back out to the file
                OutputStream os = new FileOutputStream (xmlFile);
                dp.toXml (os);
                System.out.println ("\nHopefully written to " + xmlFile);			
                */			

                /*
                // (6)
                File stylesheet = Futil.getReadFile ("select a stylesheet");
                dp.toHtml (xmlFile, stylesheet);
                */

                
                out.flush ();
                out.close ();
                
            }
            catch (IOException e) {
                System.out.println ("IOException: " + e.getMessage ());
            }
            catch (Exception e) {
                System.out.println ("Exception: " + e.getMessage ());
            }
	}//main
}//class